package edu.harvard.mgh.purcell.gplink.base_form;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.util.HashMap;
import java.util.Vector;

import javax.swing.border.TitledBorder;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

/**
 * An extention of JPanel that gets the appropreate text files, .ped and .map files.
 * @author Kathe Todd-Brown
 */
@SuppressWarnings("serial")
public class TextSelectPanel extends JPanel {
	private Forms parent;
	
	//text field that hold the .ped file name
	private GeneralUtil.UpdatingTextField PEDname, MAPname;
	private GeneralUtil.pickAFileButton selectPED, selectMAP;
	
	private JCheckBox fileCheck;
	private JComboBox fileCombo;
	
	//flags weather this is filled with a valid value or not
	public boolean validInput;
	
	public String getCommand(boolean trim){
		String ans = "";
		if(validInput ==  false){//this should never happen
			System.err.println("Invalid text selection form");
			return ans;
		}
		
		if(fileCheck.isSelected()){
			if(trim == false){
				ans = "--file "
				+ parent.processFilename(fileCombo.getSelectedItem().toString());
			}else{
				ans = parent.processFilename(fileCombo.getSelectedItem().toString());
			}
			return ans;
		}
		
		if(trim == false){
			ans = "--ped " + parent.processFilename(PEDname.getText()) 
					 + " --map " + parent.processFilename(MAPname.getText());
		}else{
			ans = parent.processFilename(PEDname.getText()) 
					 + " " + parent.processFilename(MAPname.getText());
		}
		return ans;
	}
	
	private void checkValidInput(){
		if((PEDname.getText().length() != 0
				&& MAPname.getText().length() !=0)
				|| (fileCheck.isSelected() == true
					&& fileCombo.getSelectedItem() != null
					&& !fileCombo.getSelectedItem().equals("")))
			validInput = true;
		else
			validInput = false;
		
		parent.isValidCommand();
	}
	
	private DocumentListener updateOk = new DocumentListener(){
		public void insertUpdate(DocumentEvent arg0) {
			checkValidInput();
		}
		public void removeUpdate(DocumentEvent arg0) {
			checkValidInput();			
		}
		public void changedUpdate(DocumentEvent arg0) {
			checkValidInput();			
		}	
	};
	
	/**
	 * Constucter
	 * @param p Form that contains this panel.
	 */
	public TextSelectPanel(Forms p){
		parent = p;
		
		//set the sizes and content of the fileds that hold the
		//...input files
		PEDname = new GeneralUtil.UpdatingTextField("", 10, updateOk);
		MAPname = new GeneralUtil.UpdatingTextField("", 10, updateOk);
		
		//set up buttons to trigger the previously mentioned file chooser
		selectPED = new GeneralUtil.pickAFileButton(".ped", "PED", PEDname, parent, false);
		selectMAP = new GeneralUtil.pickAFileButton(".map", "MAP", MAPname, parent, false);
		
		JPanel longPanel = new JPanel();
		longPanel.setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.ipady = 0;
		c.ipadx = 2;
		c.weighty = 1;
		c.weightx = 0;
		c.gridx = 0;
		c.gridy = 0;
		c.fill = GridBagConstraints.HORIZONTAL;
		longPanel.add(new JLabel(".ped file:"), c);
		c.gridx = 1;
		c.weightx = 1;
		longPanel.add(PEDname,c);
		c.gridx = 2;
		c.weightx = 0;
		longPanel.add(selectPED,c);
		c.gridy = 1;
		c.gridx = 0;
		longPanel.add(new JLabel(".map file:"),c);
		c.gridx = 1;
		c.weightx = 1;
		longPanel.add(MAPname,c);
		c.gridx = 2;
		c.weightx = 0;
		longPanel.add(selectMAP,c);
		
		JPanel filePanel =  new JPanel();
		filePanel.setBorder(new TitledBorder("Quick Fileset"));
		filePanel.setAlignmentX(Component.RIGHT_ALIGNMENT);
		fileCheck = new JCheckBox();
		fileCheck.setAlignmentX(Component.LEFT_ALIGNMENT);
		fileCheck.setSelected(true);
		fileCheck.addActionListener(new CheckAction());
		populatefileCombo();
		if(fileCombo.getSelectedItem() != null
			&&	fileCombo.getSelectedItem().equals(""))
			validInput = false;
		else
			validInput = true;
		fileCombo.setAlignmentX(Component.LEFT_ALIGNMENT);
		filePanel.setLayout(new BoxLayout(filePanel, BoxLayout.LINE_AXIS));
		filePanel.add(fileCheck);
		filePanel.add(fileCombo);
		filePanel.add(Box.createHorizontalGlue());
		
//		give the panel a title
		setLayout(new GridBagLayout());
		c = new GridBagConstraints();
		c.weightx = 1;
		c.weightx = 1;
		c.fill = GridBagConstraints.HORIZONTAL;
		add(filePanel, c);
		c.gridy = 1;
		add(longPanel, c);
		
	}

	private void populatefileCombo() {
		Vector<String>fileList = parent.myFrame.data.getFileList();
		//File [] fileList = frame.data.getRoot().listFiles(new textInputFilter());
		
		HashMap<String, Integer> allfileroots = new HashMap<String, Integer>();
		
		for(String file: fileList){
			if(file.endsWith(".ped") 
					|| file.endsWith(".map")){
			//take the last three off
			String fileroot = GeneralUtil.fileName(file);
			fileroot = fileroot.substring(0, fileroot.length() - 4);
			if(allfileroots.containsKey(fileroot))
				allfileroots.put(fileroot, allfileroots.get(fileroot)+1);
			else
				allfileroots.put(fileroot, new Integer(1));
			}
		}
		
		
		
		Vector <String>ans = new Vector <String> ();
		if(allfileroots.isEmpty())
			ans.add("");
		else{
			for( String key : allfileroots.keySet()){
				if(allfileroots.get(key).equals(new Integer(2)))
					if(parent.myFrame.data.isRemote(false))
						ans.add(parent.myFrame.data.getRemoteFile()+"/" +key);
					else
						ans.add(key);
			}
		}
		fileCombo = new JComboBox(ans);
		
	}
	
	private class CheckAction implements ActionListener{

		public void actionPerformed(ActionEvent e) {
			selectMAP.setEnabled(!fileCheck.isSelected());
			selectPED.setEnabled(!fileCheck.isSelected());
			fileCombo.setEnabled(fileCheck.isSelected());
			checkValidInput();
		}
		
	}

}
