package edu.harvard.mgh.purcell.gplink.forms;


import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;

import javax.swing.ButtonGroup;

import edu.harvard.mgh.purcell.gplink.base_form.*;
import edu.harvard.mgh.purcell.gplink.mainGUI.*;

/**
 * Create a form that allows the user to test for Allele
 * frequency. (plink command: --freq, --counts, --within)
 * @author Kathe
 *
 */
@SuppressWarnings("serial")
public class AFreqForm extends Forms {

	//buttons that allow the user to select the --freq and
	//...--count commands
	Forms.myRadioButton freqButton, countButton;
	//allows the user to specify an optional --within
	Forms.myRadioButton withinButton;
	//picks the --within file
	Forms.myJTextField withinField;
	//button pick the file associated with --within
	Forms.pickAFileButton pickWithin;
	
	/**
	 * creates a new Allele frequency form.
	 * @param mf MainFrame associated with this form
	 */
	public AFreqForm(MainFrame mf) {
		super(mf, "Allele Frequencies");
	}
	
	/**
	 * create the body for this form
	 */
	@Override
	protected void createBody() {
		
		//put the --freq and --count in a buton group so that
		//...the user can only use one or the other and is forced
		//...to select atleast one to excicute the form.
		ButtonGroup pickOne = new ButtonGroup();
		pickOne.add(freqButton);
		pickOne.add(countButton);
		pickOne.add(withinButton);
		
		//set the layout for the form
		body.setLayout(new GridBagLayout());
		//declare and initalze the constraits for this layout
		GridBagConstraints c = new GridBagConstraints();
		//expand all the components in this layout to fill all
		//...avaliable space
		c.fill = GridBagConstraints.BOTH;
		//add the frequency button to the layout with the given
		//...constraints
		body.add(freqButton,c);
		//move down before adding the next one
		c.gridy = 1;
		body.add(countButton,c);
		//move down again
		c.gridy = 2;
		body.add(withinButton, c);
		//let the next component resize its self to fill all avaliable
		//...space
		c.weightx = 1;
		c.gridx = 1;
		body.add(withinField, c);
		//we don't want the next component to resize
		c.weightx = 0;
		c.gridx = 2;
		
		body.add(pickWithin, c);
	}

	/**
	 * intialzie all the components of this class
	 */
	@Override
	protected void initalize() {
		
		withinField = new myJTextField(10);
		
		pickWithin = new pickAFileButton(withinField);
		pickWithin.setEnabled(false);
		
		freqButton = new myRadioButton("Frequencies (--freq)");
		freqButton.setSelected(true);
		countButton = new myRadioButton("Frequency Counts (--freq --counts)");
		withinButton = new myRadioButton("Frequencies Stratify by (--freq --within)", 
				withinField, pickWithin);
		
	}

	/**
	 * check to see if the commands selected are valid. Either
	 * --freq or --count must be selected and if --within is selected
	 * then there must be a valid file entered in the field.
	 */
	@Override
	protected boolean isBodyValid() {
		if( withinButton.isSelected() 
				&& withinField.getText().length() == 0){
//			information.setText("When --within is selected you must specify a file.");
			return false;
		}
		else 
			return true;

	}

	/**
	 * Generate the correct command line.
	 */
	@Override
	protected String processBody() {
		
		String ans = "--freq";
		if(countButton.isSelected())
			ans += " --counts";
		if(withinButton.isSelected())
			//since within takes a filename we need to throw
			//...quotes around it if we are in a window's os
			ans += " --within " + processFilename(withinField.getText());
		return ans;
	}

}
