package edu.harvard.mgh.purcell.gplink.forms;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;

import javax.swing.ButtonGroup;
import javax.swing.JSeparator;
import javax.swing.SwingConstants;

import edu.harvard.mgh.purcell.gplink.base_form.*;
import edu.harvard.mgh.purcell.gplink.mainGUI.*;
//import working.Forms.pickAFileButton;


@SuppressWarnings("serial")
public class StratAssocForm extends Forms{

	Forms.myRadioButton mhButton, mh2Button, homogButton, 
						withinButton, familyButton;
	Forms.myCheckBox ciButton, bdButton,  adjustButton;
	Forms.myJTextField withinText, ciText;
	Forms.pickAFileButton withinBrowse;
	
	static Double CI_DEFAULT = new Double(0.95);
	
	public StratAssocForm(MainFrame mf) {
		super(mf, "Stratified Analyses");
	}

	@Override
	protected void createBody() {

		body.setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.fill = GridBagConstraints.HORIZONTAL;
		c.gridwidth = 3;
		body.add(mhButton, c);
		c.gridy = 1;
		body.add(mh2Button, c);
		c.gridy = 2;
		body.add(homogButton, c);
		c.gridy = 3;
		body.add(new JSeparator(SwingConstants.HORIZONTAL), c);
		c.gridy = 4;
		body.add(familyButton, c);
		c.weightx = 0;
		c.gridy = 5;
		c.gridwidth = 1;
		body.add(withinButton, c);
		c.gridx = 1;
		c.weightx = 1;
		body.add(withinText, c);
		c.gridx = 2;
		c.weightx = 0;
		body.add(withinBrowse, c);
		c.gridx = 0;
		c.gridwidth = 3;
		c.gridy = 6;
		body.add(new JSeparator(SwingConstants.HORIZONTAL), c);
		c.gridy = 7;
		body.add(bdButton, c);
		c.gridy = 8;
		body.add(adjustButton, c);
		c.gridy = 9;
		c.gridwidth = 1;
		body.add(ciButton, c);
		c.gridx = 1;
		body.add(ciText, c);
	}

	@Override
	protected String processBody() {
		String ans = "";
		
		if(bdButton.isSelected())
			ans += " --bd";
		if(homogButton.isSelected())
			ans += " --homog";
		if(mhButton.isSelected())
			ans += " --mh";
		if(mh2Button.isSelected())
			ans += " --mh2";
		if(adjustButton.isSelected())
			ans += " --adjust";
		if(withinButton.isSelected())
			ans += " --within " + processFilename(withinText.getText());
		if(familyButton.isSelected())
			ans += " --family";
		if(ciButton.isSelected())
			ans += " --ci " + ciText.getText();
		
		ans = ans.replaceFirst(" ", "");
		return ans;
	}

	@Override
	protected boolean isBodyValid() {
		if (! (mhButton.isSelected() || mh2Button.isSelected() 
				|| homogButton.isSelected())){
//			information.setText("Must select either --mh, --mh2 or --homog.");
			return false;
		}
		
		if(!(withinButton.isSelected() || familyButton.isSelected())){
//			information.setText("Must select either --family or --within.");
			return false;
		}
		
		if(withinButton.isSelected() && withinText.getText().length() == 0 ){
//			information.setText("Must select a valid file for --within.");
			return false;
		}
			
		return true;
		/*
		return ( mhButton.isSelected() || mh2Button.isSelected() 
				|| homogButton.isSelected() ) 
						&& (  ( withinButton.isSelected() 
								&& new File(withinText.getText()).exists() ) 
							|| familyButton.isSelected() ) ;
		*/
	}

	@Override
	protected void initalize() {
		
		withinText = new myJTextField(10);
		withinBrowse = new pickAFileButton(".cluster2","CLUSTER",withinText);
		ciText = new myJTextField(CI_DEFAULT.toString(), 4);
		
		mhButton = new myRadioButton("Cochran-Mantel-Haenszel, " +
				"				SNP-DISEASE | CLUSTER (--mh)");
		bdButton = new myCheckBox("Breslow-Day test of heterogeneous " +
				"				CMH ORs (--bd) ");
		mh2Button = new myRadioButton("Cochran-Mantel-Haenszel, " +
				"				SNP-CLUSTER | DISEASE (--mh2)");
		adjustButton = new myCheckBox("Adjusted p-values (--adjust)");
		homogButton = new myRadioButton("Test of homogeneous association " +
				"				(--homog) ");
		withinButton = new myRadioButton("Cluster file (--within) ",
								withinText, withinBrowse); 
		familyButton = new myRadioButton("Cluster by family (--family)");
		ciButton = new myCheckBox("Confidence intervals (--ci) ", ciText);
		
		ButtonGroup forceOne = new ButtonGroup();
		forceOne.add(mhButton);
		mhButton.setSelected(true);
		forceOne.add(mh2Button);
		forceOne.add(homogButton);
		
		ButtonGroup forceOne2 = new ButtonGroup();
		forceOne2.add(familyButton);
		familyButton.setSelected(true);
		forceOne2.add(withinButton);
		
		}

}
