package edu.harvard.mgh.purcell.gplink.mainGUI;

import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.LinkedHashSet;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.border.TitledBorder;

import edu.harvard.mgh.purcell.gplink.data.Project;

/**
 * Dialog to delete a given operation and the files associated with it.
 * @author Kathe Todd-Brown
 */
@SuppressWarnings("serial")
public class DeleteOpDialog extends JDialog {

	JPanel outfilesPanel, infilesPanel, opPanel, buttonPanel;
	JCheckBox [] operations, outfiles, infiles;
	MainFrame mf;
	
	/**
	 * 
	 */
	ActionListener quitDialog = new ActionListener(){
		public void actionPerformed(ActionEvent event){
			dispose();
		}
	};
	
	ActionListener deleteFileOp = new ActionListener(){
		public void actionPerformed(ActionEvent event){
			File temp;
			if(mf.data.isRemote(false) == false){
				for(int i = 0; i < outfiles.length; i ++){
					if(outfiles[i].isSelected()){
						temp = new File(outfiles[i].getText());
						temp.delete();
					}
					
				}
				for(int i = 0; i < infiles.length; i ++){
					if(infiles[i].isSelected()){
						temp = new File(infiles[i].getText());
						temp.delete();
					}
					
				}
			}
			for(int i = 0; i < operations.length; i++){
				if(operations[i].isSelected()){
					mf.data.removeOperation(operations[i].getText());
				}
			}
			mf.updateViews();
			dispose();
		}
	};
	
	
	
	private void makeOpPanel(String [] opNames){
		int numOps = opNames.length;
		
		operations = new JCheckBox[numOps];
		
//		populate the operations names
		for(int i = 0; i < numOps; i ++){
			operations[i] = new JCheckBox(opNames[i]);
			operations[i].setSelected(true);
			opPanel.add(operations[i]);
		}
	}
	
	private void makeFilesPanel(String [] opNames){
		LinkedHashSet <String> files;
		
		int numOps = opNames.length;
		
		files = new LinkedHashSet <String> ();
		
		//populate the outfiles
		for(int i = 0; i < numOps; i ++){
			String[][] temp = mf.data.getOpFiles(opNames[i], Project.OUTFILE_KEY);
			for(int j = 0; j < temp[0].length; j++){
				files.add(temp[0][j]);
			}
		}
		
		int numOutfiles = (files.toArray()).length;
		
		//populate the infiles
		for(int i = 0; i < numOps; i ++){
			String[][] temp = mf.data.getOpFiles(opNames[i], Project.INFILE_KEY);
			for(int j = 0; j < temp[0].length; j++){
				files.add(temp[0][j]);
			}
		}
		
		//process the file info to checkboxes
		Object [] tempFiles = files.toArray();
		int numFiles = tempFiles.length;
		
		outfiles = new JCheckBox[numOutfiles];
		for(int i = 0; i < numOutfiles; i ++){
			outfiles[i] = new JCheckBox((String) tempFiles[i]);
			outfiles[i].setSelected(true);
			outfilesPanel.add(outfiles[i]);
			
		}
		
		infiles = new JCheckBox[numFiles - numOutfiles];
		for(int i = numOutfiles; i < numFiles; i ++){
			infiles[i-numOutfiles] = new JCheckBox((String) tempFiles[i]);
			infiles[i-numOutfiles].setSelected(false);
			infilesPanel.add(infiles[i-numOutfiles]);
		}
	}
	
	private void makeButtonsPanel(){
		JButton ok = new JButton("Delete Selection");
		JButton cancel = new JButton("Cancel");
		ok.addActionListener(deleteFileOp);
		cancel.addActionListener(quitDialog);
		buttonPanel.add(ok);
		buttonPanel.add(cancel);
		
	}
	
	public DeleteOpDialog(MainFrame givenFrame, String [] opNames){
		super(givenFrame);
		this.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new GridLayout(4,1));
		
		mf = givenFrame;
		opPanel = new JPanel();
		opPanel.setLayout(new BoxLayout(opPanel, 
				BoxLayout.PAGE_AXIS));
		opPanel.setBorder(new TitledBorder("Operations to Delete"));
		outfilesPanel = new JPanel();
		outfilesPanel.setLayout(new BoxLayout(outfilesPanel, 
				BoxLayout.PAGE_AXIS));
		outfilesPanel.setBorder(new TitledBorder("Output files to Delete"));
		infilesPanel = new JPanel();
		infilesPanel.setLayout(new BoxLayout(infilesPanel, 
				BoxLayout.PAGE_AXIS));
		infilesPanel.setBorder(new TitledBorder("Input files to Delete"));
		buttonPanel = new JPanel();
		buttonPanel.setLayout(new FlowLayout());
		
		makeOpPanel(opNames);
		if(mf.data.isRemote(false) == false){
			makeFilesPanel(opNames);
		}
		makeButtonsPanel();
		
		getContentPane().add(new JScrollPane(opPanel));
		if(mf.data.isRemote(false) == false){
			getContentPane().add(new JScrollPane(outfilesPanel));
			getContentPane().add(new JScrollPane(infilesPanel));
		}
		getContentPane().add(buttonPanel);
		
		pack();
		setVisible(true);
	}
	
}
