package edu.harvard.mgh.purcell.gplink.mainGUI;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.*;
import javax.swing.border.*;

import edu.harvard.mgh.purcell.gplink.data.Project;

/**
 * A dialog that allows the user to edit the annotations on a
 * given operation and associated files.
 * 
 * @author Kathe Todd-Brown
 */
@SuppressWarnings("serial")
public class EditOpDialog extends JDialog {

	// used to populate the fields and store the
	// ...new operations
	private Project data;

	// The components of this dialong box
	private JLabel discLabel;

	private JTextField discText;

	private JTextArea clineText;

	private JLabel[] infileLabel, outfileLabel;

	private JTextField[] infileText, outfileText;

	private JPanel input, output, buttons;

	private JScrollPane command;

	private JButton ok, cancel;

	// store the old name so that we can delete it if we
	// ...want to replace the operation
	private String oldname;

	// store the number of input files of the operation
	private int numInfile;

	// store the number of output files of the operation
	private int numOutfile;

	/**
	 * Create a dialog to edit an operations entry
	 */
	@SuppressWarnings("static-access")
	public EditOpDialog(String givenName, MainFrame givenMF) {
		super(givenMF, "Edit Operation");
		
//		 set the given variables
		data = givenMF.data;
		oldname = givenName;
		
		getContentPane().setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.fill = GridBagConstraints.BOTH;
		c.gridx = 0;
		c.gridy = 0;
		c.weightx = 0;
		discLabel = new JLabel("Description :");
		getContentPane().add(discLabel, c);
		discText = new JTextField(data.getOpDiscription(oldname), 40);
		c.gridx = 1;
		c.weightx = 1;
		getContentPane().add(discText, c);

		c.gridy = 1;
		c.gridx = 0;
		c.gridwidth = 2;
		c.weighty = 1;
		clineText = new JTextArea(data.getOpCommand(oldname));
		clineText.setEditable(false);
		command = new JScrollPane(clineText);
		getContentPane().add(command, c);
		
		input = new JPanel();
		input.setBorder(new TitledBorder("Input Files"));
		String[][] infileInfo = data.getOpFiles(oldname, Project.INFILE_KEY);
		numInfile = infileInfo[0].length;
		input.setLayout(new GridLayout(numInfile, 2));
		infileLabel = new JLabel[numInfile];
		infileText = new JTextField[numInfile];
		for (int i = 0; i < numInfile; i++) {
			infileLabel[i] = new JLabel(infileInfo[0][i]);
			input.add(infileLabel[i]);
			infileText[i] = new JTextField(infileInfo[1][i]);
			input.add(infileText[i]);
		}
		JScrollPane inscroll = new JScrollPane(input);
		//inscroll.setPreferredSize(new Dimension(100, 100));
		//inscroll.revalidate();
		c.gridy = 2;
		c.gridx = 0;
		c.gridwidth = 2;
		c.gridheight = 5;
		c.weighty = 1;
		getContentPane().add(inscroll, c);

		output = new JPanel();
		output.setBorder(new TitledBorder("Output Files"));
		String[][] outfileInfo = data.getOpFiles(oldname, Project.OUTFILE_KEY);
		numOutfile = outfileInfo[0].length;
		for (int i = 0; i < numOutfile; i++) {
			if(outfileInfo[0][i].endsWith(data.OP_STATUS_EXT))
				numOutfile --;
		}
		
		output.setLayout(new GridLayout(numOutfile, 2));
		outfileLabel = new JLabel[numOutfile];
		outfileText = new JTextField[numOutfile];
		for (int i = 0; i < numOutfile; i++) {
			if(!outfileInfo[0][i].endsWith(data.OP_STATUS_EXT)){
				outfileLabel[i] = new JLabel(outfileInfo[0][i]);
				output.add(outfileLabel[i]);
				outfileText[i] = new JTextField(outfileInfo[1][i]);
				output.add(outfileText[i]);
			}
		}
		JScrollPane outscroll = new JScrollPane(output);
		//outscroll.setPreferredSize(new Dimension(100, 100));
		//outscroll.revalidate();
		c.gridy = 7;
		getContentPane().add(outscroll, c);

		ok = new JButton("OK");
		ok.addActionListener(replaceOp);
		cancel = new JButton("Cancel");
		cancel.addActionListener(closeDialog);
		buttons = new JPanel();
		buttons.add(ok);
		buttons.add(cancel);

		c.weighty = 0;
		c.gridheight = 1;
		c.gridy = 12;
		getContentPane().add(buttons, c);

		pack();
		setVisible(true);
	}

	ActionListener replaceOp = new ActionListener() {
		public void actionPerformed(ActionEvent event) {

			String dis, cline, name;
			String[] infileName = new String[numInfile];
			String[] infileDis = new String[numInfile];
			String[] outfileName = new String[numOutfile];
			String[] outfileDis = new String[numOutfile];

			name = oldname;
			dis = EditOpDialog.this.discText.getText();
			cline = EditOpDialog.this.clineText.getText();

			for (int i = 0; i < infileLabel.length; i++) {
				infileName[i] = infileLabel[i].getText();
				infileDis[i] = infileText[i].getText();
			}

			for (int i = 0; i < outfileLabel.length && outfileLabel[i] != null; i++) {
				outfileName[i] = outfileLabel[i].getText();
				outfileDis[i] = outfileText[i].getText();
			}

			EditOpDialog.this.data.replaceOperation(EditOpDialog.this.oldname,
					cline, name, dis, infileName, infileDis, outfileName,
					outfileDis);
			EditOpDialog.this.data.frame.updateViews();
			EditOpDialog.this.dispose();
		}
	};

	ActionListener closeDialog = new ActionListener() {
		public void actionPerformed(ActionEvent event) {
			EditOpDialog.this.dispose();
		}
	};

}
